<?php

namespace Drupal\knowledge_report\Controller;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Knowledge Add It report controller.
 */
class AddItController extends ReportController implements ContainerInjectionInterface {

  /**
   * Page callback for the Add It report.
   *
   * @return array
   *   A Render API array of content created.
   */
  public function content(Request $request, $user = NULL) {

    $build = [];

    $build['knowledge_content_created_line_charts'] = [
      '#prefix'   => '<div class="charts">',
      '#view_id'      => 'knowledge_content_created',
      '#view_display' => [
        'chart_articles_created',
        $this->getLinkChart($request),
      ],
      '#attributes'   => ['class' => []],
      '#suffix'   => '</div>',
    ];

    $build['knowledge_content_created_pie_charts'] = [
      '#prefix'   => '<div class="charts">',
      '#view_id'      => 'knowledge_content_created',
      '#view_display' => [
        'chart_extension_audience',
        'chart_extension_type',
        'chart_extension_product',
      ],
      '#attributes'   => ['class' => ['chart-grid']],
      '#suffix'   => '</div>',
    ];

    $build['knowledge_content_created_table'] = [
      '#view_id'      => 'knowledge_content_created',
      '#view_display' => $user ? 'embed_user' : 'embed_everyone',
      '#attributes'   => ['class' => []],
    ];

    return $this->renderBlocks($build, $user);
  }

  /**
   * Returns a link chart based on the column order.
   */
  protected function getLinkChart(Request $request) {

    $order_by = $request->query->get('order');

    $chart = 'chart_extension_links';
    switch ($order_by) {
      case 'short_count':
        $chart = 'chart_extension_links_short';
        break;

      case 'medium_count':
        $chart = 'chart_extension_links_medium';
        break;

      case 'long_count':
        $chart = 'chart_extension_links_long';
        break;

      case 'total_count':
      default:
        $chart = 'chart_extension_links';
        break;
    }

    return $chart;
  }

}
