<?php

namespace Drupal\knowledge_report\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Knowledge Adherence report controller.
 */
class AdherenceController extends ReportController implements ContainerInjectionInterface {

  /**
   * Page callback for the Adherence report.
   *
   * @return array
   *   A Render API array of content created.
   */
  public function content(Request $request, $user = NULL) {

    $build = [];

    $build['knowledge_adherence_pie_charts'] = [
      '#prefix'   => '<div class="charts">',
      '#view_id'      => 'knowledge_adherence',
      '#view_display' => [
        'chart_extension_disposition',
        'chart_extension_leader',
        'chart_extension_coach',
        'chart_extension_learner',
      ],
      '#attributes'   => ['class' => ['chart-grid']],
      '#suffix'   => '</div>',
    ];

    $build['knowledge_adherence_table'] = [
      '#view_id'      => 'knowledge_adherence',
      '#view_display' => $user ? 'embed_user' : 'embed_everyone',
      '#attributes'   => ['class' => []],
    ];

    return $this->renderBlocks($build, $user);
  }

  /**
   * Checks access for a specific request.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   * @param int $user
   *   The user id.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function accessUser(AccountInterface $account, int $user = NULL) {

    if (is_null($user)) {
      return AccessResult::neutral();
    }
    $user = $this->entityTypeManager()->getStorage('user')->load($user);
    if (is_null($user)) {
      return AccessResult::neutral();
    }
    $has_coach = $user->get('knowledge_coach')->target_id == NULL ? FALSE : TRUE;
    $is_knowledge_worker = array_intersect([
      'knowledge_candidate',
      'knowledge_contributor',
      'knowledge_publisher',
    ], $user->getRoles());

    $has_coach_and_is_knowledge_worker = $has_coach && count($is_knowledge_worker) > 0;

    return AccessResult::allowedIf($has_coach_and_is_knowledge_worker);
  }

}
