<?php

namespace Drupal\knowledge_report\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;

/**
 * Process Adherence Controller, for creating adherence.
 */
class ProcessAdherenceController extends ReportController {

  /**
   * Page callback for the Process Adherence report.
   *
   * @return array
   *   A Render API array of content created.
   */
  public function content($user = NULL) {
    $build['jsource_adherence'] = [
      '#view_id'      => 'jsource_adherence',
      '#view_display' => 'embed',
      '#attributes'   => ['class' => []],
    ];

    return $this->renderBlocks($build, $user);
  }

  /**
   * Checks access.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   * @param int $user
   *   The user id.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account, int $user = NULL) {

    $not_coach = !array_intersect([
      'knowledge_coach',
    ], $account->getRoles());
    if ($not_coach && $account->id() != 1) {
      return AccessResult::forbidden();
    }

    if (is_null($user)) {
      return AccessResult::neutral();
    }
    $user = $this->entityTypeManager()->getStorage('user')->load($user);
    if (is_null($user)) {
      return AccessResult::neutral();
    }
    $is_coach_or_user1 = array_intersect([
      'knowledge_coach',
    ], $user->getRoles()) || $user->id() == 1;

    return AccessResult::allowedIf($is_coach_or_user1);
  }

}
