<?php

namespace Drupal\knowledge_report\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\views\Views;

/**
 * Knowledge report controller.
 */
class ReportController extends ControllerBase implements ContainerInjectionInterface {

  /**
   * Render the registered blocks as output.
   *
   * @param array $blocks
   *   An array of block items formatted for rendering a view.
   * @param int|null $contextual
   *   The contextual filter.
   *
   * @return array[]
   *   A Render API array of content revisions.
   */
  public function renderBlocks(array $blocks, $contextual): array {
    $output = [];
    // Render each block element.
    foreach ($blocks as $block) {
      $build = [];
      if (empty($block['#view_id']) || !Views::getView($block['#view_id'])) {
        $build = $block;
      }
      else {
        $view_id = $block['#view_id'];
        $display_ids = is_array($block['#view_display']) ? $block['#view_display'] : [$block['#view_display']];
        foreach ($display_ids as $index => $display_id) {
          if ($contextual) {
            $build[$view_id][$index] = views_embed_view($view_id, $display_id, $contextual);
          }
          else {
            $build[$view_id][$index] = views_embed_view($view_id, $display_id);
          }

        }
      }
      if (!isset($build['#attributes'])) {
        $build['#attributes'] = $block['#attributes'];
      }
      else {
        $build['#attributes'] = array_merge_recursive($build['#attributes'], $block['#attributes']);
      }
      if (!isset($build['#prefix'])) {
        $build['#prefix'] = array_key_exists('#prefix', $block) ? $block['#prefix'] : NULL;
      }
      else {
        $build['#prefix'] = array_merge_recursive($build['#prefix'], $block['#prefix']);
      }
      if (!isset($build['#suffix'])) {
        $build['#suffix'] = array_key_exists('#suffix', $block) ? $block['#suffix'] : NULL;
      }
      else {
        $build['#suffix'] = array_merge_recursive($build['#suffix'], $block['#suffix']);
      }

      $output[] = $build;
    }

    return [
      '#prefix'   => '<div>',
      'blocks'    => $output,
      '#suffix'   => '</div>',
      '#attached' => [
        'library' => [
          'knowledge_report/charts',
        ],
      ],
    ];
  }

}
